@@ -9,7 +9,7 @@ sub teststore {
     my @records = (
         PICA::Record->new("002@ \$0Aau\n021A \$aDas zweite Kapital\n028A \$dKarl\$aMarx"),
     );
-    my $r = PICA::Record::getrecord('t/minimal.pica');
+    my $r = PICA::Record::getrecord('t/files/minimal.pica');
     $r->delete_fields('003@');
 
     my $i=0;
@@ -19,7 +19,7 @@ sub teststore {
 
         my %result = $store->create($record);
         ok( scalar %result, "create[$i]");
-        isa_ok( $result{record}, "PICA::Record", "create[$i] returned a PICA::Record" );
+        isa_ok( $result{record}, 'PICA::Record' );
         my $id = $result{id};
         ok( $id, "create[$i] returned an id: $id" );
 
